@@ -25,7 +25,8 @@
 #' "observedProperty=urn:ogc:def:property:OGC:GroundWaterLevel",
 #' "responseFormat=text/xml",
 #' "featureOfInterest=VW_GWDP_GEOSERVER.USGS.403836085374401",sep="&")
-#' data <- importNGWMN(obs_url)
+#' 
+#'  data_returned <- importNGWMN(obs_url)
 #' 
 #' }
 #' 
@@ -43,7 +44,9 @@ importNGWMN <- function(input, asDateTime=FALSE, tz="UTC"){
     raw <- TRUE
   } else {
     returnedDoc <- getWebServiceData(input, encoding='gzip')
-    
+    if(is.null(returnedDoc)){
+      return(invisible(NULL))
+    }
     returnedDoc <- xml_root(returnedDoc)
     
   }
@@ -133,7 +136,7 @@ importNGWMN <- function(input, asDateTime=FALSE, tz="UTC"){
 #' "America/Anchorage","America/Honolulu","America/Jamaica","America/Managua","America/Phoenix", and "America/Metlakatla"
 #' @importFrom xml2 xml_attr xml_find_all xml_text 
 #' @export
-#' @examples 
+#' @examplesIf is_dataRetrieval_user()
 #' baseURL <- "https://waterservices.usgs.gov/nwis/dv/?format=waterml,2.0"
 #' URL <- paste(baseURL, "sites=01646500",
 #'      "startDT=2014-09-01",
@@ -141,8 +144,10 @@ importNGWMN <- function(input, asDateTime=FALSE, tz="UTC"){
 #'      "statCd=00003",
 #'      "parameterCd=00060",sep="&")
 #' \donttest{
+#' 
 #' timesereies <- importWaterML2(URL, asDateTime=TRUE, tz="UTC")
-#' } 
+#'  
+#' }
 importWaterML2 <- function(input, asDateTime=FALSE, tz="UTC") {
   
   returnedDoc <- check_if_xml(input)
