@@ -52,7 +52,8 @@ setAccess = function(access="public"){
   pkg.env$qwdata = "https://nwis.waterdata.usgs.gov/nwis/qwdata"
   pkg.env$stat = "https://waterservices.usgs.gov/nwis/stat/"
   pkg.env$useNat = "https://waterdata.usgs.gov/nwis/water_use"
-  pkg.env$pCode = "https://nwis.waterdata.usgs.gov/nwis/pmcodes/pmcodes"
+  pkg.env$pCode = "https://help.waterdata.usgs.gov/code/parameter_cd_query"
+  pkg.env$pCodeSingle = "https://help.waterdata.usgs.gov/code/parameter_cd_nm_query"
   # NOTE: state water use are still in: constructUseURL
 
   pkg.env$Result = "https://www.waterqualitydata.us/data/Result/search"
@@ -64,7 +65,8 @@ setAccess = function(access="public"){
   pkg.env$ProjectMonitoringLocationWeighting = "https://www.waterqualitydata.us/data/ProjectMonitoringLocationWeighting/search"
   pkg.env$ResultDetectionQuantitationLimit = "https://www.waterqualitydata.us/data/ResultDetectionQuantitationLimit/search"
   pkg.env$BiologicalMetric = "https://www.waterqualitydata.us/data/BiologicalMetric/search"
-  
+  pkg.env$Organization = "https://www.waterqualitydata.us/data/Organization/search"
+
   pkg.env$NGWMN = "https://cida.usgs.gov/ngwmn_cache/sos"
 
 }
